### R code from vignette source 'ex31.Rnw'

###################################################
### code chunk number 1: ex31.Rnw:19-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex31.Rnw:38-41
###################################################
require(lattice)
require(sp)
require(gstat)


###################################################
### code chunk number 3: ex31.Rnw:58-59
###################################################
setwd("/Users/rossiter/tmp/dgeostat")


###################################################
### code chunk number 4: ex31.Rnw:62-65
###################################################
load("tcp.RData")
ls()
str(tcp)


###################################################
### code chunk number 5: ex31.Rnw:69-70
###################################################
setwd("/Users/rossiter/data/edu/dgeostats/ex")


###################################################
### code chunk number 6: ex31.Rnw:95-97
###################################################
ts1 <- lm(clay35 ~ UTM_E + UTM_N, data=tcp)
summary(ts1)


###################################################
### code chunk number 7: ex31.Rnw:119-123
###################################################
tcp$clay35[1]
fitted(ts1)[1]
tcp$clay35[1] - fitted(ts1)[1]
residuals(ts1)[1]


###################################################
### code chunk number 8: ex31.Rnw:139-141
###################################################
hist(residuals(ts1), main="Residuls, first-order trend surface",
xlab="(Actual - Modelled), clay %")


###################################################
### code chunk number 9: ex31.Rnw:144-148
###################################################
qqnorm(residuals(ts1), main="Residuls, first-order trend surface",
       xlab="Theoretical quantiles, standardized normal distribution",
       ylab="(Actual - Modelled), clay %")
qqline(residuals(ts1))


###################################################
### code chunk number 10: ex31.Rnw:159-162
###################################################
par(mfrow=c(2,2))
plot(ts1)
par(mfrow=c(1,1))


###################################################
### code chunk number 11: ex31.Rnw:180-187
###################################################
tmp <- data.frame(e = tcp$UTM_E, n = tcp$UTM_N,
                  residuals = residuals(ts1))
coordinates(tmp) <- c("e", "n")
print(bubble(tmp, zcol="residuals",
             main="Residuals from first-order trend surface",
             sub="Clay %, 30-50 cm layer",
             xlab="UTM E", ylab="UTM N", pch=1))


###################################################
### code chunk number 12: ex31.Rnw:210-212
###################################################
ts2 <- lm(clay35 ~ I(UTM_E^2) + I(UTM_N^2) + I(UTM_E*UTM_N) + UTM_E + UTM_N, data=tcp)
summary(ts2)


###################################################
### code chunk number 13: ex31.Rnw:242-245
###################################################
ts2.step <- update(ts2, . ~ . -I(UTM_E*UTM_N) )
summary(ts2.step)
AIC(ts2, ts2.step)


###################################################
### code chunk number 14: ex31.Rnw:265-268
###################################################
ts2.step2 <- update(ts2.step, . ~ . - I(UTM_E^2) )
summary(ts2.step2)
AIC(ts2.step, ts2.step2)


###################################################
### code chunk number 15: ex31.Rnw:280-283
###################################################
par(mfrow=c(2,2))
plot(ts2.step2)
par(mfrow=c(1,1))


###################################################
### code chunk number 16: ex31.Rnw:287-294
###################################################
tmp <- data.frame(e = tcp$UTM_E,
                  n = tcp$UTM_N, residuals = residuals(ts2.step2))
coordinates(tmp) <- c("e", "n")
print(bubble(tmp, zcol="residuals",
             main="Residuals from second-order trend surface",
             sub="Clay %, 30-50 cm layer",
             xlab="UTM E", ylab="UTM N", pch=1))


###################################################
### code chunk number 17: ex31.Rnw:311-321
###################################################
summary(residuals(ts1))
summary(residuals(ts2.step2))
diff(range(residuals(ts1)))
diff(range(residuals(ts2.step2)))
h1 <- hist(residuals(ts1), breaks=seq(-35, +35, 5), plot=F)
str(h1)
h2 <- hist(residuals(ts2.step2), breaks=seq(-35, +35, 5), plot=F)
tmp <- matrix(rbind(h1$counts, h2$counts), nrow=2)
barplot(tmp, beside=T, col=c("lavender","cornsilk"), main="Paired histograms, residuals from trend surfaces", xlab="clay %",
        names.arg = h1$mids, sub="Purple: 1st-order; Yellow: 2nd-order")


###################################################
### code chunk number 18: ex31.Rnw:330-335
###################################################
tmp <- data.frame(e = tcp$UTM_E, n = tcp$UTM_N, resid1 = residuals(ts1))
coordinates(tmp) <- c("e", "n")
tmp$resid2 <- residuals(ts2.step2)
tmp$resid.diff <- tmp$resid2 - tmp$resid1
str(tmp)


###################################################
### code chunk number 19: ex31.Rnw:341-349
###################################################
extreme <- max(abs(range(tmp$resid1, tmp$resid2)))
print(bubble(tmp, zcol="resid2", main="Residuals from 2nd-order trend", pch=1, maxsize=3*max(abs(range(tmp$resid2)))/extreme, key.entries=seq(-extreme, extreme, length=8)
             ),
      split=c(1,1,2,1), more=T)
print(bubble(tmp, zcol="resid1", main="Residuals from 1st-order trend", pch=1, maxsize=3*max(abs(range(tmp$resid1)))/extreme, key.entries=seq(-extreme, extreme, length=8)
             ),
      split=c(2,1,2,1), more=F)
rm(extreme)


###################################################
### code chunk number 20: ex31.Rnw:380-383
###################################################
print(bubble(tmp, zcol="resid.diff",
             main="2nd-order less 1st-order residuals",
             pch=1, col=c("blue4","red4")))


###################################################
### code chunk number 21: ex31.Rnw:394-395
###################################################
rm(h1, h2, tmp)


###################################################
### code chunk number 22: ex31.Rnw:406-408
###################################################
coordinates(tcp) <- c("UTM_E", "UTM_N")
str(tcp)


###################################################
### code chunk number 23: ex31.Rnw:417-419
###################################################
ts1 <- lm(clay35 ~ coordinates(tcp), data=tcp)
summary(ts1)


###################################################
### code chunk number 24: ex31.Rnw:430-438
###################################################
tmp <- data.frame(coordinates(tcp), residuals = residuals(ts1))
coordinates(tmp) <- c("UTM_E", "UTM_N")
print(
    bubble(tmp, zcol="residuals",
             main="Residuals from first-order trend surface",
             sub="Clay %, 30-50 cm layer",
             xlab="UTM E", ylab="UTM N", pch=1)
    )


###################################################
### code chunk number 25: ex31.Rnw:447-449
###################################################
ts2 <- lm(clay35 ~ I(coordinates(tcp)^2) + I(coordinates(tcp)[,1]*coordinates(tcp)[,2]) + coordinates(tcp), data=tcp)
summary(ts2)


