### R code from vignette source 'ex41.Rnw'

###################################################
### code chunk number 1: ex41.Rnw:19-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=65, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex41.Rnw:36-39
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex41.Rnw:72-73
###################################################
setwd("/Users/rossiter/tmp/dgeostat")


###################################################
### code chunk number 4: ex41.Rnw:76-79
###################################################
load("tcp.RData")
ls()
str(tcp)


###################################################
### code chunk number 5: ex41.Rnw:83-84
###################################################
setwd("/Users/rossiter/data/edu/dgeostats/ex")


###################################################
### code chunk number 6: ex41.Rnw:89-90
###################################################
summary(lm(clay35 ~ UTM_N + UTM_E, data=tcp))


###################################################
### code chunk number 7: ex41.Rnw:95-99
###################################################
coordinates(tcp) <- ~  UTM_E + UTM_N
gr <- expand.grid(UTM_E =seq(659000, 704000, by=500), UTM_N =seq(310000, 343000, by=500), KEEP.OUT.ATTRS=F)
coordinates(gr) <- ~ UTM_E + UTM_N
str(gr)


###################################################
### code chunk number 8: ex41.Rnw:104-105
###################################################
ts1 <- krige(clay35 ~ UTM_E +  UTM_N, loc = tcp, newdata = gr, model = NULL)


###################################################
### code chunk number 9: ex41.Rnw:111-124
###################################################
require(lattice)
print(levelplot(var1.pred ~ UTM_E + UTM_N, as.data.frame(ts1),
          col.regions=bpy.colors(64), asp="iso",
          main="First-order trend surface, clay %, 30-50~cm layer",
          sub="Sample points overprinted as post-plot",
          xlab="UTM E", ylab="UTM N",
          panel=function(x,y,z, ...) {
            panel.levelplot(x, y, z, ...)
            panel.grid(h=-1,v=-1, col="gray", lty=1)
            panel.points(coordinates(tcp),
                         cex=3*tcp$clay35/max(tcp$clay35),
                         pch=1, col="white")
          }))


###################################################
### code chunk number 10: ex41.Rnw:133-134
###################################################
rm(tcp, gr, ts1)


###################################################
### code chunk number 11: ex41.Rnw:163-166
###################################################
data(jura)
ls()
help(jura)


###################################################
### code chunk number 12: ex41.Rnw:175-176
###################################################
str(jura.pred)


###################################################
### code chunk number 13: ex41.Rnw:187-188
###################################################
str(jura.grid)


###################################################
### code chunk number 14: ex41.Rnw:201-204
###################################################
class(jura.pred)
coordinates(jura.pred) <- ~ Xloc + Yloc
class(jura.pred)


###################################################
### code chunk number 15: ex41.Rnw:211-217
###################################################
class(jura.grid)
coordinates(jura.grid) <- ~ Xloc + Yloc
class(jura.grid)
gridded(jura.grid) <- TRUE
class(jura.grid)
# fullgrid(jura.grid) <- TRUE


###################################################
### code chunk number 16: ex41.Rnw:234-238
###################################################
print(spplot(jura.grid, zcol="Rock", 
             col.regions=topo.colors(nlevels(jura.grid$Rock)),
             key.space="right", 
             main="Rock types, Jura"))


###################################################
### code chunk number 17: ex41.Rnw:254-261
###################################################
print(xyplot(Yloc ~ Xloc, as.data.frame(jura.pred),
             groups=jura.pred$Rock,
             cex=2*jura.pred$Co/max(jura.pred$Co), pch=1,
             asp="iso", xlab="East", ylab="North",
             main="Co concentration in topsoils, Jura",
             auto.key=T)
)


###################################################
### code chunk number 18: ex41.Rnw:276-278
###################################################
m.co.rt <- lm(Co ~ Rock, data=jura.pred)
summary(m.co.rt)


###################################################
### code chunk number 19: ex41.Rnw:291-292
###################################################
by(jura.pred$Co, jura.pred$Rock, mean)


###################################################
### code chunk number 20: ex41.Rnw:305-306
###################################################
head(predict(m.co.rt, newdata=jura.grid@data))


###################################################
### code chunk number 21: ex41.Rnw:311-317
###################################################
co.reclass <-
  data.frame(Rock=jura.grid$Rock,
             Co=as.ordered(round(predict(m.co.rt,
               newdata=jura.grid@data),2)))
coordinates(co.reclass) <- coordinates(jura.grid)
gridded(co.reclass) <- TRUE


###################################################
### code chunk number 22: ex41.Rnw:322-325
###################################################
print(spplot(co.reclass, zcol="Co",
             col.regions=bpy.colors(nlevels(jura.grid$Rock)),
             main="Predicted Co concentration in topsoils, Jura"))


###################################################
### code chunk number 23: ex41.Rnw:344-346
###################################################
co.split <- split(as.data.frame(jura.pred)$Co, jura.pred$Rock)
sapply(co.split, sd)


###################################################
### code chunk number 24: ex41.Rnw:357-359
###################################################
data.frame(sapply(co.split, t.test)["conf.int",], row.names=c("lower","upper"))
data.frame(sapply(co.split, t.test, conf.level=0.99)["conf.int",], row.names=c("lower","upper"))


###################################################
### code chunk number 25: ex41.Rnw:373-374 (eval = FALSE)
###################################################
## rm(co.reclass, co.split)


