### R code from vignette source 'ex4a1.Rnw'

###################################################
### code chunk number 1: ex4a1.Rnw:24-28
###################################################
options(prompt="> ", continue="+ ", digits=5, width=65, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex4a1.Rnw:41-44
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex4a1.Rnw:51-52 (eval = FALSE)
###################################################
## load("JuraEx4.RData")


###################################################
### code chunk number 4: ex4a1.Rnw:56-57
###################################################
load("/Users/rossiter/data/edu/dgeostats/ex/ds/jura/cooked/JuraEx4.RData")


###################################################
### code chunk number 5: ex4a1.Rnw:69-74
###################################################
par(mfrow=c(2,2))
hist(jura.cal$Co, col="lightblue", breaks=20, main="Co, Jura calibration samnple", xlab="Co (ppm)")
for (i in 1:3)
  hist(rnorm(length(jura.cal$Co), mean=mean(jura.cal$Co), sd=sd(jura.cal$Co)), col="lavender", breaks=20, main="Random numbers, mean/sd as Jura Co", xlab="Co (ppm)", sub=paste("Sample",i))
par(mfrow=c(1,1))


###################################################
### code chunk number 6: ex4a1.Rnw:91-94
###################################################
plot(ecdf(jura.cal$Co), do.points=F, verticals=T, main="Empirical Cumulative Distribution Function", xlab="Co (ppm), Jura soils", sub="Theoretical ECDF: green")
xvals <- seq(min(jura.cal$Co), max(jura.cal$Co), by=.1)
points(x=xvals, y=pnorm(xvals, mean=mean(jura.cal$Co), sd=sd(jura.cal$Co)), col="green", type="s")


###################################################
### code chunk number 7: ex4a1.Rnw:114-116
###################################################
qqCo <- qqnorm(jura.cal$Co, plot.it=F)
str(qqCo)


###################################################
### code chunk number 8: ex4a1.Rnw:124-126
###################################################
plot(qqCo)
qqline(jura.cal$Co)


###################################################
### code chunk number 9: ex4a1.Rnw:132-136
###################################################
head(sort(qqCo$x))
head(sort(qqCo$y))
tail(sort(qqCo$x))
tail(sort(qqCo$y))


###################################################
### code chunk number 10: ex4a1.Rnw:145-149
###################################################
head(order(qqCo$x))
head(order(qqCo$y))
qqCo.s <- data.frame(score = qqCo$x[order(qqCo$y)], Co = qqCo$y[order(qqCo$y)])
str(qqCo.s)


###################################################
### code chunk number 11: ex4a1.Rnw:156-157
###################################################
jura.cal$Cd.norm <- qqnorm(jura.cal$Cd, plot.it=F)$x


###################################################
### code chunk number 12: ex4a1.Rnw:173-175
###################################################
v <- variogram(Cd.norm ~ 1, jura.cal)
print(plot(v, pl=T, pch=20))


###################################################
### code chunk number 13: ex4a1.Rnw:180-182
###################################################
(vmf <- fit.variogram(v,vgm(0.6,"Sph",1, 0.4)))
print(plot(v, model=vmf, pl=T, pch=20))


###################################################
### code chunk number 14: ex4a1.Rnw:187-188
###################################################
vmf[2,"psill"]/sum(vmf[,"psill"])


###################################################
### code chunk number 15: ex4a1.Rnw:196-201
###################################################
v.c <- variogram(Co ~ 1, jura.cal)
(vmf.c <- fit.variogram(v.c, vgm(10, "Sph", 1.2, 5)))
print(plot(v.c, pl=T, pch=20, model=vmf.c))
vmf.c[2,"range"]
vmf.c[2,"psill"]/sum(vmf.c[,"psill"])


###################################################
### code chunk number 16: ex4a1.Rnw:226-228
###################################################
k <- krige(Cd.norm ~ 1, jura.cal, newdata=jura.grid, model=vmf, beta=0)
summary(k@data)


###################################################
### code chunk number 17: ex4a1.Rnw:231-234
###################################################
print(spplot(k, z="var1.pred", contour=T, 
             at=seq(-2.5,+2.5, by=.2),
             col.regions=terrain.colors(64), main="SK, normal score transform, Co", xlab="E", ylab="N"))


###################################################
### code chunk number 18: ex4a1.Rnw:243-248
###################################################
print(spplot(k, z="var1.var", col.regions=topo.colors(64),
             contour=T,
             at=seq(0.4,1.1, by=0.05),
             main="SK variance, normal score transform, Co",
             xlab="E", ylab="N"))


###################################################
### code chunk number 19: ex4a1.Rnw:265-269
###################################################
par(mfrow=c(1,2))
hist(k$var1.pred, main="Predicted quantiles", breaks=seq(-2,+2, by=0.2), col="lavender", freq=F)
hist(jura.cal$Co, main="Sample values", sub="Co (ppm)", breaks=0:18, col="lightblue", freq=F)
par(mfrow=c(1,1))


###################################################
### code chunk number 20: ex4a1.Rnw:276-277
###################################################
str(approx(qqCo.s$score, qqCo.s$Co, xout=k$var1.pred))


###################################################
### code chunk number 21: ex4a1.Rnw:284-285
###################################################
approx(qqCo.s$score, qqCo.s$Co, xout=-1.57)


###################################################
### code chunk number 22: ex4a1.Rnw:292-303
###################################################
plot(qqCo.s$Co ~ qqCo.s$score,
     main="Co concentration (ppm) vs. normal score",
     xlim=c(-1.8,-1.4), ylim=c(3,4), type="b",
     xlab="score", ylab="Co (ppm)")
abline(v=-1.57)
abline(h=approx(qqCo.s$score, qqCo.s$Co, xout=-1.57))
points(approx(qqCo.s$score, qqCo.s$Co, xout=-1.57),
       cex=2, col="red", pch=20)
text(approx(qqCo.s$score, qqCo.s$Co, xout=-1.57),
     "Interpolated point for normal score -1.57",
     adj=(c(0.7, -0.8)))


###################################################
### code chunk number 23: ex4a1.Rnw:309-311
###################################################
k$Co.pred <- approx(qqCo.s$score, qqCo.s$Co, xout=k$var1.pred)$y
summary(k$Co.pred); summary(jura.cal$Co)


###################################################
### code chunk number 24: ex4a1.Rnw:318-323
###################################################
print(spplot(k, zcol="Co.pred", pretty=T, contour=T,
             at=0:16, col.regions=bpy.colors(64),
             main="Predicted values, Co (ppm)",
             xlab="UTM E", ylab="UTM N",
             scales=list(draw=T)))


###################################################
### code chunk number 25: ex4a1.Rnw:336-337
###################################################
k.grid <- krige(Co ~ 1, loc=jura.cal, newdata=jura.grid, model=vmf)


###################################################
### code chunk number 26: ex4a1.Rnw:340-347
###################################################
print(spplot(k.grid, zcol="var1.pred",
pretty=T,
contour=T,
at=0:16,
col.regions=bpy.colors(64),
main="Predicted values, Co (ppm)", xlab="UTM E", ylab="UTM N",
scales=list(draw=T)))


###################################################
### code chunk number 27: ex4a1.Rnw:354-356
###################################################
summary(k.grid$var1.pred)
summary(k$Co.pred)


###################################################
### code chunk number 28: ex4a1.Rnw:363-364 (eval = FALSE)
###################################################
## rm(xvals, v, vm, vmf, v.c, vmf.c, qqCo, qqCo.s, k, k.grid, i)


