### R code from vignette source 'ex51.Rnw'

###################################################
### code chunk number 1: ex51.Rnw:20-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex51.Rnw:113-114 (eval = FALSE)
###################################################
## load("JuraEx4.RData")


###################################################
### code chunk number 3: ex51.Rnw:122-125
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 4: ex51.Rnw:128-131
###################################################
load("/Users/rossiter/tmp/dgeostat/JuraEx4.RData")
#
k.grid <- krige(Co ~ 1, loc = jura.cal, newdata = jura.raster, model = vmf) 


###################################################
### code chunk number 5: ex51.Rnw:143-145
###################################################
bk.grid <- krige(Co ~ 1, loc=jura.cal, newdata=jura.raster, model=vmf, block=c(0.05, 0.05))
summary(bk.grid)


###################################################
### code chunk number 6: ex51.Rnw:165-167
###################################################
range(k.grid$var1.pred, bk.grid$var1.pred)
range(k.grid$var1.var, bk.grid$var1.var)


###################################################
### code chunk number 7: ex51.Rnw:172-174
###################################################
(at.pred <- 2:16)
(at.var <- seq(0, 15.5, by=0.5))


###################################################
### code chunk number 8: ex51.Rnw:187-201
###################################################
plot.1 <- spplot(k.grid, zcol="var1.pred",
                 col.regions=bpy.colors(64),
                 main="Predicted values, Co (ppm) [OK]",
                 xlab="UTM E", ylab="UTM N",
scales=list(draw=T),at=at.pred)
#
plot.2 <- spplot(bk.grid, zcol="var1.pred",
                 col.regions=bpy.colors(64),
                 main="Predicted values, Co (ppm) [BK]",
                 xlab="UTM E", ylab="UTM N",
scales=list(draw=T), at=at.pred)
#
print(plot.1, split=c(1, 1, 2, 1), more=T)
print(plot.2, split=c(2, 1, 2, 1), more=F)


###################################################
### code chunk number 9: ex51.Rnw:207-223
###################################################
plot.1 <- spplot(k.grid, zcol="var1.var",
                 col.regions=topo.colors(64),
                 main="Kriging variance, Co (ppm^2) [OK]",
                 xlab="UTM E", ylab="UTM N",
                 scales=list(draw=T),
                 at=seq(0, 15.5, by=0.5))
#
plot.2 <- spplot(bk.grid, zcol="var1.var",
                 col.regions=topo.colors(64),
                 main="Kriging variance, Co (ppm^2) [BK]",
                 xlab="UTM E", ylab="UTM N",
                 scales=list(draw=T),
                 at=seq(0, 15.5, by=0.5))
#
print(plot.1, split=c(1, 1, 2, 1), more=T)
print(plot.2, split=c(2, 1, 2, 1), more=F)


###################################################
### code chunk number 10: diff.ok.bk
###################################################
diff.ok.bk <- data.frame(
    pred = round(k.grid$var1.pred - bk.grid$var1.pred, 2),
    var = round(k.grid$var1.var - bk.grid$var1.var,3))
summary(diff.ok.bk)
coordinates(diff.ok.bk) <- coordinates(bk.grid)


###################################################
### code chunk number 11: ex51.Rnw:248-252
###################################################
print(spplot(diff.ok.bk, zcol="pred", cuts=8,
             col.regions=cm.colors(8),
             main="OK - BK 50x50 predictions, Co (ppm)",
             key.space="right"))


###################################################
### code chunk number 12: ex51.Rnw:255-259
###################################################
print(spplot(diff.ok.bk, zcol="var", cuts=8,
             col.regions=terrain.colors(8),
             main="OK - BK 50x50 kriging variances, Co (ppm^2)",
             key.space="right"))


###################################################
### code chunk number 13: ex51.Rnw:274-275
###################################################
rm(at.pred, at.var, plot.1, plot.2)


###################################################
### code chunk number 14: ex51.Rnw:332-335
###################################################
penta.var <- function(h, a) {
  if (h > a) 1 else ((15/8)*(h/a) - (5/4)*((h/a)^3) + (3/8) * ((h/a)^5)) }
# penta.var(0.05, 1.5239)


