### R code from vignette source 'ex52.Rnw'

###################################################
### code chunk number 1: uk-13-show-pred
###################################################
print(spplot(jura.cal, zcol="Co", col.regions=bpy.colors(64),
             cuts=seq(1,19,by=2), key.space="right",
             main="Co (ppm)", xlab="E", ylab="N",
             pch=1, cex=1.5))


###################################################
### code chunk number 2: ex52.Rnw:124-126
###################################################
str(jura.raster@bbox)
str(jura.cal@bbox)


###################################################
### code chunk number 3: ex52.Rnw:131-133
###################################################
coordnames(jura.raster) <- c("X", "Y")
str(jura.raster@bbox)


###################################################
### code chunk number 4: ex52.Rnw:138-143
###################################################
ts1 <- krige(Co ~ X + Y, loc=jura.cal,
             newdata=jura.raster, model=NULL)
print(spplot(ts1, zcol="var1.pred", contour=T,
             pretty=T, col.regions=terrain.colors(64),
             main="1st-order trend surface, Co"))


###################################################
### code chunk number 5: ex52.Rnw:154-156
###################################################
(lm.co.xy <- lm(Co ~ coordinates(jura.cal), data=jura.cal))
summary(lm.co.xy)


###################################################
### code chunk number 6: ex52.Rnw:172-174
###################################################
coefficients(lm.co.xy)
atan2(coefficients(lm.co.xy)[2], coefficients(lm.co.xy)[3])*(180/pi)


###################################################
### code chunk number 7: ex52.Rnw:207-209
###################################################
v <- variogram(Co ~ 1, loc=jura.cal, cutoff=1.6)
vr <- variogram(Co ~ coordinates(jura.cal), loc=jura.cal, cutoff=1.6)


###################################################
### code chunk number 8: ex52.Rnw:214-215
###################################################
(compare.v <- data.frame(np = v$np, separation = v$dist, gamma.ok = v$gamma, gamma.uk = vr$gamma, gamma.dif = v$gamma-vr$gamma))


###################################################
### code chunk number 9: ex52.Rnw:220-229
###################################################
plot(compare.v$gamma.ok ~ compare.v$separation, pch=20,
     col="blue", type="b",
     xlab="Separation", ylab="Semivariance", 
     ylim=c(0, max(compare.v$gamma.ok, compare.v$gamma.uk)),
     main="Variogram, Jura Cobalt (ppm)",
     sub="OK: blue, UK: green")
points(compare.v$gamma.uk ~ compare.v$separation, pch=20,
       col="green", type="b")
abline(h=0, lty=1)


###################################################
### code chunk number 10: ex52.Rnw:245-257
###################################################
vmf
vrm <- vgm(12, "Pen", 1.2, 1.4) 
plot.1 <- plot(vr, pl=T, model=vrm,
               main="Jura Co; residuals from 1st-order trend",
               sub="Eyeball model")
(vrmf <- fit.variogram(vr, vrm))
attributes(vrmf)$SSErr
plot.2 <- plot(vr, pl=T, model=vrmf,
               main="Jura Co; residuals from 1st-order trend",
               sub="gstat Fitted model")
print(plot.1, split=c(1,1,2,1), more=T)
print(plot.2, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 11: ex52.Rnw:263-265
###################################################
vmf$range-vrmf$range
vmf$psill-vrmf$psill


###################################################
### code chunk number 12: ex52.Rnw:277-280
###################################################
vrmf$psill[1]
vmf$psill[1]
(vrmf$psill[1]-vmf$psill[1])/vmf$psill[1]


###################################################
### code chunk number 13: ex52.Rnw:287-289
###################################################
(vrmf.2 <- fit.variogram(vr, vgm(12, "Pen", 1.2, vmf[1,"psill"]), fit.sills=c(F,T)))
attributes(vrmf.2)$SSErr


###################################################
### code chunk number 14: ex52.Rnw:295-298
###################################################
print(vrmf)
attributes(vrmf)$SSErr
rm(vrmf.2)


###################################################
### code chunk number 15: ex52.Rnw:320-322
###################################################
uk.grid <- krige(Co ~ X + Y, loc = jura.cal, newdata = jura.raster, model = vrmf)
summary(uk.grid)


###################################################
### code chunk number 16: plot-uk-pred
###################################################
print(spplot(uk.grid, zcol="var1.pred",
             col.regions=bpy.colors(64),
             pretty=T, cuts=8,
             main="UK predictions, Co (ppm)",
             key.space="right",
             panel=function(x,y,z, ...) {
                 panel.levelplot(x, y, z, ...)
                 panel.grid(h=-1,v=-1, col="gray", lty=1)
                 panel.points(coordinates(jura.cal),
                              cex=3*jura.cal$Co/max(jura.cal$Co),
                              pch=1, col="white")
                 }))


###################################################
### code chunk number 17: plot-uk-var
###################################################
print(spplot(uk.grid, zcol="var1.var",
             col.regions=topo.colors(64),
             pretty=T, cuts=8,
             main="UK predictions variances, Co (ppm^2)",
             key.space="right",
             panel=function(x,y,z, ...) {
                 panel.levelplot(x, y, z, ...)
                 panel.grid(h=-1,v=-1, col="gray", lty=1)
                 panel.points(coordinates(jura.cal),
                              pch=1, col="white")
                 }))


###################################################
### code chunk number 18: ex52.Rnw:364-368
###################################################
diff.ok.uk <- data.frame(pred = k.grid$var1.pred - uk.grid$var1.pred,
                         var = k.grid$var1.var - uk.grid$var1.var)
str(diff.ok.uk)
coordinates(diff.ok.uk) <- coordinates(uk.grid)


###################################################
### code chunk number 19: ex52.Rnw:373-377
###################################################
print(spplot(diff.ok.uk, zcol="pred", pretty=T, cuts=8,
             col.regions=cm.colors(64),
             main="OK - UK predictions, Co (ppm)",
             key.space="right"))


###################################################
### code chunk number 20: ex52.Rnw:382-386
###################################################
print(spplot(diff.ok.uk, zcol="var", pretty=T, cuts=8,
             col.regions=terrain.colors(64),
             main="OK - UK kriging variances, Co (ppm^2)",
             key.space="right"))


###################################################
### code chunk number 21: ex52.Rnw:397-398
###################################################
rm(diff.ok.uk)


###################################################
### code chunk number 22: ex52.Rnw:420-434
###################################################
uk13.grid <- krige(Co ~ X + Y, loc = jura.cal,
                   newdata = jura.raster, model = vrmf,
                   maxdist=1.3, nmin=16)
print(spplot(uk13.grid, zcol="var1.pred",
             col.regions=bpy.colors(64),
             main="UK predictions, 1.3km radius, Co (ppm)",
             xlab="E", ylab="N",
             panel=function(x,y,z, ...) {
                 panel.levelplot(x, y, z, ...)
                 panel.grid(h=-1,v=-1, col="gray", lty=1)
                 panel.points(coordinates(jura.cal),
                              cex=3*jura.cal$Co/max(jura.cal$Co),
                              pch=1, col="white")
                 }))


###################################################
### code chunk number 23: ex52.Rnw:443-450
###################################################
uk13.grid$pred.diff <- uk13.grid$var1.pred - uk.grid$var1.pred
summary(uk13.grid$pred.diff)
print(spplot(uk13.grid, zcol="pred.diff",
             col.regions=cm.colors(64),
             main="UK prediction differences, Co (ppm)",
             sub="1.3km radius vs.\ all points",
             xlab="E", ylab="N"))


###################################################
### code chunk number 24: ex52.Rnw:456-464
###################################################
uk13.grid$var.diff <- uk.grid$var1.var - uk13.grid$var1.var
summary(uk13.grid$var.diff)
print(spplot(uk13.grid, zcol="var.diff",
             pretty=T, cuts=8,
             col.regions=terrain.colors(64),
             main="UK prediction variance differences, Co (ppm^2)",
             sub="all points vs. 1.3km radius",
             xlab="E", ylab="N"))


###################################################
### code chunk number 25: ok-pure-nugget
###################################################
(vmn <- vgm(0, "Pen", vmf[2, "range"], sum(vmf[,"psill"])))
ok.n <- krige(Co ~ 1, loc=jura.cal,
              newdata=jura.raster, model=vmn)
summary(ok.n@data)
ok.n.w <- krige(Co ~ 1, loc=jura.cal,
                newdata=jura.raster, model=vmn,
                maxdist=1.3, nmin=16)
summary(ok.n.w@data)
mean(jura.cal$Co)


###################################################
### code chunk number 26: ok-pure-nugget-show-pred
###################################################
print(spplot(ok.n.w, zcol="var1.pred",
             col.regions=bpy.colors(64),
             main="OK predictions, 1.3km radius, Co (ppm)",
             sub="pure nugget variogram model",
             xlab="E", ylab="N",
             panel=function(x,y,z, ...) {
                 panel.levelplot(x, y, z, ...)
                 panel.grid(h=-1,v=-1, col="gray", lty=1)
                 panel.points(coordinates(jura.cal),
                              cex=3*jura.cal$Co/max(jura.cal$Co),
                              pch=1, col="white")
                 }))


###################################################
### code chunk number 27: ok-pure-nugget-show-var
###################################################
print(spplot(ok.n.w, zcol="var1.var",
             col.regions=topo.colors(64),
             main="OK prediction variances, 1.3km radius, Co (ppm^2)",
             sub="pure nugget variogram model",
             xlab="E", ylab="N",
             panel=function(x,y,z, ...) {
                 panel.levelplot(x, y, z, ...)
                 panel.grid(h=-1,v=-1, col="gray", lty=1)
                 panel.points(coordinates(jura.cal),
                              pch=1, col="white")
                 }))


