### R code from vignette source 'ex61.Rnw'

###################################################
### code chunk number 1: ex61.Rnw:20-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex61.Rnw:28-31
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex61.Rnw:51-58
###################################################
load("/Users/rossiter/tmp/dgeostat/JuraEx4.RData")
if (!is.element("vmf", objects())){
  vmf <- fit.variogram(variogram(Co ~ 1, loc=jura.cal, cutoff=1.6), vgm(12.5, "Pen", 1.2, 1.5))
}
if (!is.element("k.val", objects())){
  k.val <- krige(Co ~ 1, loc = jura.cal, newdata = jura.val, model=vmf)
}


###################################################
### code chunk number 4: ex61.Rnw:85-93
###################################################
summary(k.val$var1.pred); summary(jura.val$Co)
pred.error <- k.val$var1.pred - jura.val$Co
summary(pred.error)
hist(pred.error,
     main="Prediction errors: Predicted - Actual, OK, Jura",
     xlab="Co (mg kg-1)", col="lightblue")
pred.error <- as.data.frame(pred.error)
coordinates(pred.error) <- coordinates(jura.val)


###################################################
### code chunk number 5: ex61.Rnw:97-100
###################################################
print(bubble(pred.error,
             main="Prediction Errors: Predicted by OK - Actual",
             sub="Co (mg kg-1)"))


###################################################
### code chunk number 6: ex61.Rnw:115-122
###################################################
summary(k.val$var1.pred-jura.val$Co)
(mpe <- mean(k.val$var1.pred-jura.val$Co))
(rmse <- sqrt(mean((jura.val$Co - k.val$var1.pred)^2)))
summary(jura.cal$Co)
mpe/mean(jura.cal$Co)
rmse/sd(jura.cal$Co)
rmse/IQR(jura.cal$Co)


###################################################
### code chunk number 7: ex61.Rnw:147-155
###################################################
plot.lims=c(floor(min(jura.val$Co, k.val$var1.pred)),
  ceiling(max(jura.val$Co, k.val$var1.pred)))
plot(jura.val$Co ~ k.val$var1.pred, asp=1, pch=20,
     col="blue", ylab="Actual", xlab="Predicted",
     xlim=plot.lims,
     ylim=plot.lims, main="Jura Co, 100 evaluation points")
abline(0,1, lty=2, col="red")
grid()


###################################################
### code chunk number 8: ex61.Rnw:169-174
###################################################
lm.val <- lm(jura.val$Co ~ k.val$var1.pred)
summary(lm.val)
par(mfrow=c(1,2))
plot(lm.val, which=1:2)
par(mfrow=c(1,1))


###################################################
### code chunk number 9: ex61.Rnw:196-203
###################################################
plot(jura.val$Co ~ k.val$var1.pred, asp=1, pch=20,
     col="blue", xlab="Predicted", ylab="Actual",
     xlim=plot.lims, ylim=plot.lims,
     main="Jura Co, 100 evaluation points",
     sub="1:1 line red, regression green")
abline(0,1, lty=2, col="red")
abline(lm.val, col="green"); grid()


###################################################
### code chunk number 10: ex61.Rnw:220-221
###################################################
coef(summary(lm.val))


###################################################
### code chunk number 11: ex61.Rnw:226-227
###################################################
lm.val$df


###################################################
### code chunk number 12: ex61.Rnw:234-235
###################################################
qt(.95, lm.val$df)


###################################################
### code chunk number 13: ex61.Rnw:242-245
###################################################
t.val <- qt(.95, lm.val$df)
coef(summary(lm.val))[2,1] - t.val * coef(summary(lm.val))[2,2]
coef(summary(lm.val))[2,1] + t.val * coef(summary(lm.val))[2,2]


###################################################
### code chunk number 14: ex61.Rnw:260-261
###################################################
summary(lm.val)$adj.r.squared


###################################################
### code chunk number 15: ex61.Rnw:269-270 (eval = FALSE)
###################################################
## rm(pred.error, rmse, mpe, plot.lims, lm.val, t.val)


###################################################
### code chunk number 16: ex61.Rnw:316-317
###################################################
rm(pred.error, rmse, mpe, plot.lims, lm.val, t.val)


###################################################
### code chunk number 17: ex61.Rnw:342-343
###################################################
k.cv <- krige.cv(Co ~ 1, loc=jura.cal, model=vmf)


###################################################
### code chunk number 18: ex61.Rnw:360-363
###################################################
print(bubble(k.cv, zcol="residual",
             main="OK Cross-validation prediction errors",
             sub="Co (mg kg-1)"))


###################################################
### code chunk number 19: ex61.Rnw:376-382
###################################################
summary(k.cv)
(mpe <- mean(k.cv$residual))
mpe/mean(jura.cal$Co)
(rmse <- sqrt(mean(k.cv$residual^2)))
rmse/sd(jura.cal$Co)
rmse/IQR(jura.cal$Co)


###################################################
### code chunk number 20: ex61.Rnw:405-406
###################################################
mean(k.cv$residual^2/k.cv$var1.var)


###################################################
### code chunk number 21: ex61.Rnw:422-423 (eval = FALSE)
###################################################
## rm(mpe, rmse)


###################################################
### code chunk number 22: ex61.Rnw:432-442
###################################################
summary(lm.cv <- lm(jura.cal$Co ~ k.cv$var1.pred))
plot.lims=c(floor(min(jura.cal$Co, k.cv$var1.pred)),
  ceiling(max(jura.cal$Co, k.cv$var1.pred)))
plot(jura.cal$Co ~ k.cv$var1.pred, asp=1, pch=20,
     col="blue", xlab="Predicted", ylab="Actual",
     xlim=plot.lims, ylim=plot.lims,
     main="Jura Co, cross-validation points",
     sub="1:1 line red, regression green")
abline(0,1, lty=2, col="red")
abline(lm.cv, col="green"); grid()


###################################################
### code chunk number 23: ex61.Rnw:448-451
###################################################
par(mfrow=c(1,2))
plot(lm.cv, which=1:2)
par(mfrow=c(1,1))


###################################################
### code chunk number 24: ex61.Rnw:457-461
###################################################
t.val <- qt(.95, lm.cv$df)
coef(summary(lm.cv))[2,1] - t.val * coef(summary(lm.cv))[2,2]
coef(summary(lm.cv))[2,1] + t.val * coef(summary(lm.cv))[2,2]
rm(t.val)


###################################################
### code chunk number 25: ex61.Rnw:466-467
###################################################
summary(lm.cv)$adj.r.squared


###################################################
### code chunk number 26: ex61.Rnw:492-493 (eval = FALSE)
###################################################
## rm(lm.cv)


###################################################
### code chunk number 27: ex61.Rnw:506-507
###################################################
jura.cal[ix <- which.max(jura.cal$Co),]


###################################################
### code chunk number 28: ex61.Rnw:514-516
###################################################
v <- variogram(Co ~ 1, loc=jura.cal, cutoff=1.6)
vv <- variogram(Co ~ 1, loc=jura.cal[-ix,], cutoff=1.6)


###################################################
### code chunk number 29: ex61.Rnw:524-528
###################################################
(sv <- sum(v$np))
(svv <- sum(vv$np))
print(sv-svv)
print(1-svv/sv)


###################################################
### code chunk number 30: ex61.Rnw:535-542
###################################################
(vvmf <- fit.variogram(vv, vmf))
(diff.psill <- vvmf[2,"psill"] - vmf[2,"psill"])
(diff.range <- vvmf[2,"range"] - vmf[2,"range"])
(diff.nugget <- vvmf[1,"psill"] - vmf[1,"psill"])
((diff.psill/vmf[2,"psill"])*100)
((diff.range/vmf[2,"range"])*100)
((diff.nugget/vmf[1,"psill"])*100)


###################################################
### code chunk number 31: ex61.Rnw:555-561
###################################################
plot(v$gamma ~ v$dist, xlim=c(0,1.3), ylim=c(0,16), pch=20, cex=1.5, xlab="Separation (km)", ylab="Semivariance", type="b", lty=2)
title(main="Empirical variogram, Co concentration in soils", sub="black: all points; red: less largest value")
points(vv$gamma ~ vv$dist, col="red", pch=1, cex=1.5, type="b", lty=2)
grid()
lines(variogramLine(vmf, maxdist=1.3))
lines(variogramLine(vvmf, maxdist=1.3), col="red")


###################################################
### code chunk number 32: ex61.Rnw:575-576
###################################################
kv.cv <- krige.cv(Co ~ 1, loc=jura.cal, model=vvmf)


###################################################
### code chunk number 33: ex61.Rnw:581-582
###################################################
summary(k.cv$residual - kv.cv$residual)


###################################################
### code chunk number 34: ex61.Rnw:594-595 (eval = FALSE)
###################################################
## rm(ix, sv, svv, v, vv, vvmf, diff.psill, diff.range, diff.nugget, kv.cv)


###################################################
### code chunk number 35: ex61.Rnw:669-670
###################################################
rm(mpe, rmse, lm.cv, ix, sv, svv, v, vv, vvmf, diff.psill, diff.range, diff.nugget)


###################################################
### code chunk number 36: ex61.Rnw:688-691
###################################################
if (!is.element("k.val", objects())){
  k.val <- krige(Co ~ 1, loc = jura.cal, newdata = jura.val, model = vmf)
  }


###################################################
### code chunk number 37: ex61.Rnw:700-701
###################################################
summary(sqrt(k.val$var1.var))


