### R code from vignette source 'ex71.Rnw'

###################################################
### code chunk number 1: ex71.Rnw:20-24
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex71.Rnw:28-31
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex71.Rnw:44-46 (eval = FALSE)
###################################################
## load("JuraEx4.RData")
## ls()


###################################################
### code chunk number 4: ex71.Rnw:49-51
###################################################
load("/Users/rossiter/data/edu/dgeostats/ex/ds/jura/cooked/JuraEx4.RData")
ls()


###################################################
### code chunk number 5: ex71.Rnw:54-55
###################################################
str(jura.cal)


###################################################
### code chunk number 6: ex71.Rnw:85-88
###################################################
i12 <- (jura.cal$Co < 12)
summary(i12)
sum(i12)/length(i12)


###################################################
### code chunk number 7: ex71.Rnw:113-116
###################################################
jura.cal.ind <- data.frame(Co = jura.cal$Co, i12 = i12, i12n = as.numeric(i12))
str(jura.cal.ind)
rm(i12)


###################################################
### code chunk number 8: ex71.Rnw:125-127
###################################################
coordinates(jura.cal.ind) <- coordinates(jura.cal)
str(jura.cal.ind)


###################################################
### code chunk number 9: ex71.Rnw:142-143
###################################################
print(spplot(jura.cal.ind, zcol="i12n",  col.regions=c("red", "green"), main="Indicator: Co < 12 ppm"))


###################################################
### code chunk number 10: ex71.Rnw:165-167
###################################################
vi <- variogram(i12 ~ 1, loc=jura.cal.ind, cloud=T)
print(plot(vi, main="Indicator variogram cloud, Co < 12 ppm"))


###################################################
### code chunk number 11: ex71.Rnw:190-192
###################################################
vi <- variogram(i12 ~ 1, loc=jura.cal.ind)
print(plot(vi, pl=T, main="Indicator variogram, Co < 12 ppm"))


###################################################
### code chunk number 12: ex71.Rnw:205-207
###################################################
(vimf <- fit.variogram(vi, vgm(0.15, "Exp", 0.8, 0.07)))
print(plot(vi, pl=T, main="Modelled indicator variogram, Co < 12 ppm", model=vimf))


###################################################
### code chunk number 13: ex71.Rnw:215-216
###################################################
vimf[2, "range"]*3


###################################################
### code chunk number 14: ex71.Rnw:223-224
###################################################
vimf[1, "psill"]/sum(vimf[, "psill"])


###################################################
### code chunk number 15: ex71.Rnw:237-239
###################################################
ki <- krige(i12 ~ 1, loc=jura.cal.ind, newdata=jura.grid, model=vimf)
summary(ki)


###################################################
### code chunk number 16: ex71.Rnw:254-257
###################################################
ki$var1.pred <- pmin(1, ki$var1.pred)
ki$var1.pred <- pmax(0, ki$var1.pred)
summary(ki@data)


###################################################
### code chunk number 17: ex71.Rnw:268-275
###################################################
plot.ik12 <- spplot(ki, zcol="var1.pred",
                    at=seq(0,1, by=0.04),
                    col.regions=heat.colors(64),
                    main="Probability Co < 12 ppm",
                    sub="Indicator Kriging",
                    contour=T)
print(plot.ik12)


###################################################
### code chunk number 18: ex71.Rnw:289-299
###################################################
layout.ind.pts <- list("sp.points", jura.cal.ind,
                       col=ifelse(jura.cal.ind$i12, "green", "blue"), pch=20)
print(spplot(ki, zcol="var1.pred",
             at=seq(0,1, by=0.04),
             col.regions=heat.colors(64),
             main="Probability Co < 12 ppm",
             sub="Observations: <12 ppm green, >= 12 ppm blue",
             sp.layout=list(layout.ind.pts)
))
rm(layout.ind.pts)


###################################################
### code chunk number 19: ex71.Rnw:312-313
###################################################
rm(vi, ki)


###################################################
### code chunk number 20: ex71.Rnw:328-330
###################################################
ki.val <- krige(i12 ~ 1, loc=jura.cal.ind, newdata=jura.val, model=vimf)
summary(ki.val)


###################################################
### code chunk number 21: ex71.Rnw:339-341
###################################################
i12.val <- (jura.val$Co < 12)
summary(i12.val)


###################################################
### code chunk number 22: ex71.Rnw:348-350
###################################################
sum(i12.val)/length(i12.val)
sum(jura.cal.ind$i12)/length(jura.cal.ind$i12)


###################################################
### code chunk number 23: ex71.Rnw:361-368
###################################################
compare <- data.frame(
                      id = as.numeric(row.names(ki.val@data)),
                      i12 = i12.val,
                      pred = ki.val$var1.pred
                      )
coordinates(compare) <- coordinates(ki.val)
str(compare)


###################################################
### code chunk number 24: ex71.Rnw:373-376
###################################################
order(compare$pred)
compare.sorted <- compare[order(compare$pred),]
str(compare.sorted)


###################################################
### code chunk number 25: ex71.Rnw:385-387
###################################################
compare.sorted[1, ]
compare.sorted[dim(compare.sorted)[1], ]


###################################################
### code chunk number 26: ex71.Rnw:396-399
###################################################
head(row.names(compare.sorted@data))
row.names(compare.sorted@data) <- 1:dim(compare.sorted)[1]
head(row.names(compare.sorted@data))


###################################################
### code chunk number 27: ex71.Rnw:404-405 (eval = FALSE)
###################################################
## compare.sorted@data[,c("i12","pred")]


###################################################
### code chunk number 28: ex71.Rnw:442-451
###################################################
plot(compare$i12 ~ compare$pred, pch="|", cex=1.5,
xlab="Predicted probability of TRUE indicator",
xlim=c(0,1),
yaxt="n", ylab="",
col=ifelse(compare$i12, "green", "red"),
main="Evaluation: Indicator kriging, Co < 12",
sub="Green/Red: indicator TRUE/FALSE"
)
abline(v=sum(i12.val)/length(i12.val), lty=2, col="darkblue")


###################################################
### code chunk number 29: ex71.Rnw:464-465
###################################################
rm(jura.cal.ind, i12.val, compare, compare.sorted)


###################################################
### code chunk number 30: ex71.Rnw:484-487
###################################################
jura.cal.ind <- data.frame(i12 = (jura.cal$Co < 12))
coordinates(jura.cal.ind) <- coordinates(jura.cal)
k.cv<-krige.cv(i12 ~ 1, loc=jura.cal.ind, model=vimf)


###################################################
### code chunk number 31: ex71.Rnw:490-491
###################################################
summary(k.cv@data)


###################################################
### code chunk number 32: ex71.Rnw:504-505
###################################################
k.cv$var1.pred <- pmin(1, k.cv$var1.pred)


###################################################
### code chunk number 33: ex71.Rnw:516-524
###################################################
plot(coordinates(k.cv), asp=1,
     col=ifelse(k.cv$observed, "green", "red"),
     cex=0.2+2*k.cv$var1.pred,
     xlab="E (km)", ylab="N (km)",
     main="Probability of TRUE indicator",
     sub="Actual indicator: red/green = FALSE/TRUE"
)
grid()


###################################################
### code chunk number 34: ex71.Rnw:539-548
###################################################
plot(k.cv$observed ~ k.cv$var1.pred, pch="|", cex=1.5,
xlab="Predicted probability of TRUE indicator",
xlim=c(0,1),
yaxt="n", ylab="",
col=ifelse(k.cv$observed, "green", "red"),
main="Cross-validation: IK, p(Co < 12)",
sub="Green/Red: indicator TRUE/FALSE"
)
abline(v=sum(k.cv$observed)/length(k.cv$observed), lty=2, col="darkblue")


###################################################
### code chunk number 35: ex71.Rnw:559-560
###################################################
rm(k.cv, jura.cal.ind)


