### R code from vignette source 'ex72.Rnw'

###################################################
### code chunk number 1: ex72.Rnw:19-23
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
# rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex72.Rnw:27-30
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex72.Rnw:33-34
###################################################
load("/Users/rossiter/data/edu/dgeostats/ex/ds/jura/cooked/JuraEx4.RData")


###################################################
### code chunk number 4: ex72.Rnw:86-88
###################################################
hist(jura.cal$Co, col="lightblue", border="darkblue",
main="Co concentration, Jura soils", sub="mg kg-1")


###################################################
### code chunk number 5: ex72.Rnw:102-106
###################################################
v <- variogram(Co ~ 1, loc = jura.cal, cutoff = 1.6)
vmf <- fit.variogram(v, vgm(12.5, "Pen", 1.2, 1.5))
k.grid <- krige(Co ~ 1, loc = jura.cal, newdata = jura.grid, model = vmf) 
summary(k.grid)


###################################################
### code chunk number 6: ex72.Rnw:122-123
###################################################
(t.val <- qt(0.975, length(jura.cal$Co) - 1))


###################################################
### code chunk number 7: ex72.Rnw:130-133
###################################################
k.grid$lcl <- k.grid$var1.pred - (t.val * sqrt(k.grid$var1.var))
k.grid$ucl <- k.grid$var1.pred + (t.val * sqrt(k.grid$var1.var))
summary(k.grid@data)


###################################################
### code chunk number 8: ex72.Rnw:142-144
###################################################
k.grid$lcl <- pmax(k.grid$lcl, 0)
summary(k.grid@data)


###################################################
### code chunk number 9: ex72.Rnw:153-154
###################################################
(at.pred <- seq(floor(min(k.grid$lcl)), ceiling(max(k.grid$ucl)), by=1))


###################################################
### code chunk number 10: ex72.Rnw:164-186
###################################################
#
plot.1 <- spplot(k.grid, zcol="lcl", at = at.pred,
                 contour=T, col.regions=bpy.colors(64),
                 main="Lower 95% confidence limit",
                 xlab="UTM E", ylab="UTM N",
                 scales=list(draw=T))
#
plot.2 <- spplot(k.grid, zcol="var1.pred", at = at.pred,
                 contour=T, col.regions=bpy.colors(64),
                 main="Predicted values, Co (ppm)",
                 xlab="UTM E", ylab="UTM N",
                 scales=list(draw=T))
#
plot.3 <- spplot(k.grid, zcol="ucl", at = at.pred,
                 contour=T, col.regions=bpy.colors(64),
                 main="Upper 95% confidence limit",
                 xlab="UTM E", ylab="UTM N",
                 scales=list(draw=T))
#
print(plot.1, split=c(1, 1, 2, 2), more=T)
print(plot.2, split=c(1, 2, 2, 2), more=T)
print(plot.3, split=c(2, 1, 2, 2), more=F)


###################################################
### code chunk number 11: ex72.Rnw:202-204
###################################################
k.grid$ucl12 <- (k.grid$ucl >= 12)
summary(k.grid$ucl12)


###################################################
### code chunk number 12: ex72.Rnw:211-212
###################################################
1 - (sum(k.grid$ucl12)/length(k.grid$ucl12))


###################################################
### code chunk number 13: ex72.Rnw:218-226
###################################################
plot(coordinates(k.grid), 
     pch=20,    
     cex=0.5, asp=1,
     col=ifelse(k.grid$ucl12, "red", "green"),
     xlab="E", ylab="N",
     main="Areas possibly > 12 ppm Co",
     sub="possibly contaminated areas shown in red")
grid()


###################################################
### code chunk number 14: ex72.Rnw:246-251
###################################################
target <- 12
k.grid$var1.var[1]
target - k.grid$var1.pred[1]
sqrt(k.grid$var1.var[1])
(w <- (target - k.grid$var1.pred[1])/sqrt(k.grid$var1.var[1]))


###################################################
### code chunk number 15: ex72.Rnw:262-263
###################################################
pt(w, length(jura.cal$Co))


###################################################
### code chunk number 16: ex72.Rnw:275-281
###################################################
k.grid$p12 <- pt((target - k.grid$var1.pred)/sqrt(k.grid$var1.var),
                 length(jura.cal$Co))
plot.p12 <- spplot(k.grid, zcol="p12", col.regions=heat.colors(64),
                   at=seq(0,1, by=0.04), contour=T,
                   main="Probability < 12 ppm Co", sub="Parametric")
print(plot.p12)


###################################################
### code chunk number 17: ex72.Rnw:291-293
###################################################
print(plot.p12, split=c(1,1,2,1), more=T)
print(plot.ik12, split=c(2,1,2,1), more=F)


###################################################
### code chunk number 18: ex72.Rnw:310-312
###################################################
k.val <- krige(Co ~ 1, loc=jura.cal, newdata=jura.val, model=vmf)
summary(k.val)


###################################################
### code chunk number 19: ex72.Rnw:319-323
###################################################
(t.val <- qt(0.975, length(jura.cal$Co) - 1)) 
k.val$ucl <- k.val$var1.pred + (t.val * sqrt(k.val$var1.var))
k.val$ucl12 <- (k.val$ucl >= 12) 
str(k.val@data)


###################################################
### code chunk number 20: ex72.Rnw:330-332
###################################################
sum(k.val$ucl12)/length(k.val$ucl12)
sum((jura.val$Co >= 12))/length(jura.val$Co)


###################################################
### code chunk number 21: ex72.Rnw:341-345
###################################################
(t.val <- qt(0.75, length(jura.cal$Co) - 1)) 
k.val$ucl75 <- k.val$var1.pred + (t.val * sqrt(k.val$var1.var))
k.val$ucl75.12 <- (k.val$ucl75 >= 12) 
sum(k.val$ucl75.12)/length(k.val$ucl75.12)


###################################################
### code chunk number 22: ex72.Rnw:352-354
###################################################
sum(k.val$var1.pred >= 12)/length(k.val$var1.pred)
sum((jura.val$Co >= 12))/length(jura.val$Co)


###################################################
### code chunk number 23: ex72.Rnw:367-369
###################################################
k.val$p12 <- pt((12 - k.val$var1.pred)/sqrt(k.val$var1.var), length(jura.cal$Co))
summary(k.val@data)


###################################################
### code chunk number 24: ex72.Rnw:378-383
###################################################
compare <- data.frame(
                      i12 = (jura.val$Co < 12),
                      p12 = k.val$p12
                      )
summary(compare)


###################################################
### code chunk number 25: ex72.Rnw:390-399
###################################################
plot(compare$i12 ~ compare$p12, pch="|", cex=1.5,
xlab="Predicted probability of TRUE indicator",
xlim=c(0,1),
yaxt="n", ylab="",
col=ifelse(compare$i12, "green", "red"),
main="Evaluation: OK, p(Co < 12)",
sub="Green/Red: indicator TRUE/FALSE"
)
abline(v=sum(compare$i12)/length(compare$i12), lty=2, col="darkblue")


###################################################
### code chunk number 26: ex72.Rnw:411-412 (eval = FALSE)
###################################################
## rm(v, vmf, w, t.val, plot.p12, plot.ik12, k.grid, k.val, target, compare)


