### R code from vignette source 'ex8a1.Rnw'

###################################################
### code chunk number 1: ex8a1.Rnw:20-25
###################################################
options(prompt="> ", continue="+ ", digits=5, width=70, show.signif.stars=T)
par(mfrow=c(1,1))
## clean workspace
rm(list=ls())
setwd("~/data/edu/dgeostats/ex")


###################################################
### code chunk number 2: ex8a1.Rnw:33-36
###################################################
require(sp)
require(gstat)
require(lattice)


###################################################
### code chunk number 3: ex8a1.Rnw:55-66
###################################################
p <- SpatialPolygons(
                     list(Polygons(
                              list(
                                   Polygon(
                                           matrix(c(0,0, 0,1, 1,1, 1,0, 0,0), byrow=T, nrow=5, ncol=2) # matrix
                                           ) # Polygon
                              ) # list of Polygon
                              , ID=1 ) # Polygons, with identifier
                          ) # list of Polygons
                     ) # Spatial Polygons
summary(p)


###################################################
### code chunk number 4: ex8a1.Rnw:77-79
###################################################
p <- SpatialPolygonsDataFrame(p, data=data.frame(id=1))
str(p)


###################################################
### code chunk number 5: ex8a1.Rnw:91-92
###################################################
(max.dist <- sqrt(((bbox(p)[1,"max"] - bbox(p)[1,"min"])^2) + ((bbox(p)[2,"max"] - bbox(p)[2,"min"])^2)))


###################################################
### code chunk number 6: ex8a1.Rnw:103-111
###################################################
## discretize the polygon as a 100x100 regular grid
resolution <- 100
grid <- spsample(p, n=resolution^2, type="regular")
class(grid)
gridded(grid) = T
class(grid)
fullgrid(grid) = T
class(grid)


###################################################
### code chunk number 7: ex8a1.Rnw:129-130
###################################################
(vm <- vgm(psill=1, model="Exp", range=max.dist/(3*3), 0))


###################################################
### code chunk number 8: ex8a1.Rnw:148-153
###################################################
obj.k <- function(scheme, f="mean") {
  k <- krige(z ~ 1, loc=scheme, model=vm, newdata=grid)
  return(f(k$var1.var))
}
class(obj.k)


###################################################
### code chunk number 9: ex8a1.Rnw:167-168
###################################################
prec <- 3


###################################################
### code chunk number 10: ex8a1.Rnw:190-195
###################################################
n.pts <- 10
set.seed(621)
scheme <- SpatialPointsDataFrame(spsample(p, n=n.pts, type="random"), data.frame(z=rep(0,n.pts)))
scheme@coords <- round(scheme@coords, prec)
print(scheme)


###################################################
### code chunk number 11: ex8a1.Rnw:212-214
###################################################
fix.pts <- data.frame(x = c(.2,.6), y=c(.6, .2), z=0)
coordinates(fix.pts) <- ~ x + y


###################################################
### code chunk number 12: ex8a1.Rnw:224-233
###################################################
print(spplot(p, xlab="E", ylab="N", col.regions="slategray3",
             main="Initial sampling scheme",
             sub="Fixed: yellow; Moveable: white",
             scales=list(draw=T),
             sp.layout = list(list("sp.points", scheme,
               col="white", pch=20, cex=1.6),
               list("sp.points", fix.pts, col="yellow",
                    pch=20, cex=1.6))
       ))


###################################################
### code chunk number 13: ex8a1.Rnw:243-244
###################################################
(fitness <- obj.k(rbind(fix.pts, scheme), mean))


###################################################
### code chunk number 14: ex8a1.Rnw:257-273
###################################################
k <- krige(z ~ 1, loc=rbind(fix.pts,scheme), model=vm,
           newdata=grid)
gridded(k) <- T; fullgrid(k) <- T
pts.s <- list("sp.points", scheme, col="white",
              pch=20, cex=1.6)
pts.f <- list("sp.points", fix.pts, col="blue",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Initial sampling scheme"),
             sub=paste("Mean, max kriging variance:",
               round(mean(k$var1.var),4),";",
               round(max(k$var1.var),4)),
             sp.layout = list(pts.s, pts.f)
             ))
rm(k, pts.s, pts.f)


###################################################
### code chunk number 15: ex8a1.Rnw:337-358
###################################################
max.shift <- round(max.dist*sqrt(2)/6, prec)
n <- 200; sum.delta.fit <-0; i <- 0
while (i < n) {
  pt <- sample(1:n.pts, 1)
  pt.old <- coordinates(scheme)[pt,]
  repeat {
      xnew <- pt.old[1] + runif(1, min=-max.shift, max=max.shift)
      ynew <- pt.old[2] + runif(1, min=-max.shift, max=max.shift)
      pt.new <- data.frame(x = xnew, y = ynew)
      coordinates(pt.new) <- c(1,2)
      if (!is.na(over(pt.new,p))) break
      }
   scheme.try <- scheme
   scheme.try@coords[pt,] <- c(xnew, ynew)
   fitness.new <- obj.k(rbind(fix.pts, scheme.try), mean)
  if (fitness.new > fitness) {
    sum.delta.fit <- sum.delta.fit + (fitness.new - fitness)
    i <- i+1 }
 }
mean.delta.fit <- sum.delta.fit/n
rm(max.shift, n, i, pt, pt.old, xnew, ynew, scheme.try, fitness.new)


###################################################
### code chunk number 16: ex8a1.Rnw:366-367
###################################################
print(paste("Average positive change in fitness:",round(mean.delta.fit,4)))


###################################################
### code chunk number 17: ex8a1.Rnw:376-379
###################################################
(metr.temp <- metr.temp.init <- -mean.delta.fit/log(0.8))
rm(mean.delta.fit)
alpha <- 0.99


###################################################
### code chunk number 18: ex8a1.Rnw:393-394
###################################################
step <- 1


###################################################
### code chunk number 19: ex8a1.Rnw:422-425
###################################################
exp(-1/256)
exp(-1/512)
exp(-1/128)


###################################################
### code chunk number 20: ex8a1.Rnw:441-458
###################################################
plot(1:1200, exp(-(0:1199)/192), type="l",
     xlab="step", ylab="proportion",
     main="Proportion of maximum distance to shift at each step",
     sub="Decay factor shown by colour")
grid()
lines(1:1200, exp(-(0:1199)/64), col="green")
lines(1:1200, exp(-(0:1199)/128), col="blue")
lines(1:1200, exp(-(0:1199)/256), col="red")
lines(1:1200, exp(-(0:1199)/512), col="purple")
lines(1:1200, exp(-(0:1199)/1024), col="brown")
text(800, .7, "64", col="green")
text(800, .75, "128", col="blue")
text(800, .8, "192")
text(800, .85, "256", col="red")
text(800, .9, "512", col="purple")
text(800, .95, "1024", col="brown")
abline(h=0.01, lty=2)


###################################################
### code chunk number 21: ex8a1.Rnw:465-466
###################################################
for (i in c(64, 128, 192, 256, 512, 1024)) print(floor(-i * log(1/100) + 1))


###################################################
### code chunk number 22: ex8a1.Rnw:473-474
###################################################
(max.shift <- round((max.dist*sqrt(2)/6), prec))


###################################################
### code chunk number 23: ex8a1.Rnw:494-497
###################################################
set.seed(621)
(pt <- sample(1:n.pts, 1))
pt.old <- coordinates(scheme)[pt,]


###################################################
### code chunk number 24: ex8a1.Rnw:507-515
###################################################
set.seed(621)
repeat {
  xnew <- round(pt.old[1] + runif(1, min=-max.shift, max=max.shift),prec)
  ynew <- round(pt.old[2] + runif(1, min=-max.shift, max=max.shift),prec)
  pt.new <- data.frame(x = xnew, y = ynew)
  coordinates(pt.new) <- ~ x + y
  if (!is.na(over(pt.new,p))) break
}


###################################################
### code chunk number 25: ex8a1.Rnw:522-525
###################################################
	scheme.try <- scheme
	scheme.try@coords[pt,] <- c(xnew, ynew)
	(fitness.new <- obj.k(rbind(scheme.try, fix.pts), mean))


###################################################
### code chunk number 26: ex8a1.Rnw:542-548
###################################################
	plot(coordinates(scheme), xlim=c(bbox(p)[1,"min"],bbox(p)[1,"max"]), ylim=c(bbox(p)[2,"min"],bbox(p)[2,"max"]), xaxs="i", yaxs="i", xlab="E", ylab="N",
		main=paste("Spatial simulated annealing, step",step), asp=1, sub=paste("Current fitness:",round(fitness,4),"; new fitness",round(fitness.new,4)))
	grid()
    points(coordinates(fix.pts), col="blue", pch=20) # fixed points
	points(xnew, ynew, col="red", cex=2) # scheme points
	arrows(pt.old[1], pt.old[2], xnew, ynew, length=0.05) # new point


###################################################
### code chunk number 27: ex8a1.Rnw:570-579
###################################################
if (fitness.new < fitness) {
		scheme <- scheme.try; fitness <- fitness.new;
        print("Better scheme, accepted")
	} else
		if (runif(1) < (metr.temp * exp(fitness - fitness.new))) {
			scheme <- scheme.try; fitness <- fitness.new;
        print("Worse scheme, accepted")
	} else
        print("Worse scheme, rejected")


###################################################
### code chunk number 28: ex8a1.Rnw:589-592
###################################################
n.steps <- 300
fits <- matrix(nrow = n.steps, ncol=4)
colnames(fits) <- c("actual","proposed","max.shift","temperature")


###################################################
### code chunk number 29: ex8a1.Rnw:597-632
###################################################
(time <- system.time(
  for (step in 1:n.steps) {
	max.shift <- max.dist*0.5*round(exp(-(step-1)/256), prec);

	metr.temp <- metr.temp * alpha;

	pt <- sample(1:n.pts, 1)
    pt.old <- coordinates(scheme)[pt,]
	repeat {
		xnew <- round(pt.old[1] + runif(1, min=-max.shift, max=max.shift),prec)
        ynew <- round(pt.old[2] + runif(1, min=-max.shift, max=max.shift),prec)
        pt.new <- data.frame(x = xnew, y = ynew)
        coordinates(pt.new) <- ~ x + y
        if (!is.na(over(pt.new,p))) break
		}

	scheme.try <- scheme
	scheme.try@coords[pt,] <- c(xnew, ynew)
	fitness.new <- obj.k(rbind(fix.pts, scheme.try), mean)

	if (fitness.new < fitness) {
		scheme <- scheme.try;
		fitness <- fitness.new
      } else if (runif(1) < (metr.temp * exp(fitness - fitness.new))) {
			scheme <- scheme.try;
			fitness <- fitness.new
	} 
    fits[step,"actual"] <- fitness;
	fits[step,"proposed"] <- fitness.new;
	fits[step,"max.shift"] <- max.shift;
	fits[step,"temperature"] <- metr.temp;

}
)
)


###################################################
### code chunk number 30: ex8a1.Rnw:635-636
###################################################
print(time)


###################################################
### code chunk number 31: show.evolution (eval = FALSE)
###################################################
## plot(1:n.steps, fits[,"actual"], xlab="Step",
##      ylab="Fitness function", type="l",
##      main="Fitness function vs. step",
##      sub="Black: actual; red: proposed",
##      ylim=c(min(fits[,1]), max(fits[,2])))
## lines(1:n.steps, fits[,"proposed"], type="l",
##       col="red", lty=2, pch=3)


###################################################
### code chunk number 32: ex8a1.Rnw:658-659
###################################################
plot(1:n.steps, fits[,"actual"], xlab="Step",
     ylab="Fitness function", type="l",
     main="Fitness function vs. step",
     sub="Black: actual; red: proposed",
     ylim=c(min(fits[,1]), max(fits[,2])))
lines(1:n.steps, fits[,"proposed"], type="l",
      col="red", lty=2, pch=3)


###################################################
### code chunk number 33: ex8a1.Rnw:671-675
###################################################
plot(1:n.steps, fits[,"temperature"],
     xlab="Step", ylab="Temperature",
     type="l", main="Temperature vs. step")
grid()


###################################################
### code chunk number 34: ex8a1.Rnw:686-689
###################################################
plot(1:n.steps, fits[,"max.shift"], xlab="Step", ylab="Shift", type="l", main="Maximum shift vs. step")
grid()
print(paste("Maximum shift after",n.steps,":",round(fits[n.steps,"max.shift"],4)))


###################################################
### code chunk number 35: ex8a1.Rnw:702-718
###################################################
print(scheme)
k <- krige(z ~ 1, loc=rbind(fix.pts,scheme),
           model=vm, newdata=grid)
gridded(k) <- T; fullgrid(k) <- T
pts.s <- list("sp.points", scheme, col="white",
              pch=20, cex=1.6)
pts.f <- list("sp.points", fix.pts, col="blue",
              pch=20, cex=1.6)
print(spplot(k, zcol="var1.var",
             col.regions=heat.colors(64),
             main=paste("Final sampling scheme (MEAN_OK)"),
             sub=paste("Mean, max kriging variance:",
               round(mean(k$var1.var),4),";",
               round(max(k$var1.var),4)),
             sp.layout = list(pts.s, pts.f)
             ))


###################################################
### code chunk number 36: ex8a1.Rnw:730-731 (eval = FALSE)
###################################################
## rm(list=ls())


###################################################
### code chunk number 37: ex8a1.Rnw:787-788
###################################################
rm(list=ls())


